@@ -19,13 +19,16 @@
    Boston, MA 02110-1301, USA.
 */
 
+// TODO: remove me
+#undef QT_NO_CAST_FROM_ASCII
+
 #include "main.h"
 #include "kio_version.h"
 #include "kioexecdinterface.h"
 
-#include <QtCore/QFile>
-#include <QtCore/QDir>
-#include <QtCore/Q_PID>
+#include <QFile>
+#include <QDir>
+#include <Q_PID>
 
 #include <job.h>
 #include <copyjob.h>
@@ -37,7 +40,6 @@
 #include <KRun>
 #include <KService>
 #include <KLocalizedString>
-#include <KAboutData>
 #include <KDBusService>
 
 #include <QCommandLineParser>
@@ -193,6 +195,7 @@ void KIOExec::slotRunApp()
     KService service(QStringLiteral("dummy"), command, QString());
 
     QList<QUrl> list;
+    list.reserve(fileList.size());
     // Store modification times
     QList<FileInfo>::Iterator it = fileList.begin();
     for (; it != fileList.end() ; ++it) {
@@ -205,7 +208,7 @@ void KIOExec::slotRunApp()
     KIO::DesktopExecParser execParser(service, list);
     QStringList params = execParser.resultingArguments();
 
-    qDebug() << "EXEC " << params.join(QStringLiteral(" "));
+    qDebug() << "EXEC " << params.join(QLatin1Char(' '));
 
     // propagate the startup identification to the started process
     KStartupInfoId id;
@@ -282,10 +285,8 @@ int main(int argc, char **argv)
     KDBusService service(KDBusService::Multiple);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("tempfiles") , i18n("Treat URLs as local files and delete them afterwards")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("suggestedfilename"), i18n("Suggested file name for the downloaded file"), "filename"));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("suggestedfilename"), i18n("Suggested file name for the downloaded file"), QStringLiteral("filename")));
     parser.addPositionalArgument(QStringLiteral("command"), i18n("Command to execute"));
     parser.addPositionalArgument(QStringLiteral("urls"), i18n("URL(s) or local file(s) used for 'command'"));
 
