@@ -188,10 +188,10 @@ PreviewJob::PreviewJob(const KFileItemList &items,
         d->enabledPlugins = *enabledPlugins;
     } else {
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-        d->enabledPlugins = globalConfig.readEntry("Plugins", QStringList()
-                            << QStringLiteral("directorythumbnail")
-                            << QStringLiteral("imagethumbnail")
-                            << QStringLiteral("jpegthumbnail"));
+        d->enabledPlugins = globalConfig.readEntry("Plugins", QStringList {
+                                                                  QStringLiteral("directorythumbnail"),
+                                                                  QStringLiteral("imagethumbnail"),
+                                                                  QStringLiteral("jpegthumbnail")});
     }
 
     // Return to event loop first, determineNextFile() might delete this;
@@ -369,7 +369,7 @@ void PreviewJobPrivate::startPreview()
         } else {
             cacheWidth = cacheHeight = 256;
         }
-        thumbPath = thumbRoot + (cacheWidth == 128 ? "normal/" : "large/");
+        thumbPath = thumbRoot + QLatin1String(cacheWidth == 128 ? "normal/" : "large/");
         if (!QDir(thumbPath).exists()) {
             if (QDir().mkpath(thumbPath)) { // Qt5 TODO: mkpath(dirPath, permissions)
                 QFile f(thumbPath);
@@ -419,8 +419,7 @@ void PreviewJob::setIgnoreMaximumSize(bool ignoreSize)
 void PreviewJobPrivate::cleanupTempFile()
 {
     if (!tempName.isEmpty()) {
-        Q_ASSERT(!QFileInfo(tempName).isDir());
-        Q_ASSERT(QFileInfo(tempName).isFile());
+        Q_ASSERT((!QFileInfo(tempName).isDir() && QFileInfo(tempName).isFile()) || QFileInfo(tempName).isSymLink());
         QFile::remove(tempName);
         tempName.clear();
     }
@@ -445,6 +444,7 @@ void PreviewJobPrivate::determineNextFile()
         succeeded = false;
         items.removeFirst();
         KIO::Job *job = KIO::stat(currentItem.item.url(), KIO::HideProgressInfo);
+        job->addMetaData(QStringLiteral("thumbnail"), QStringLiteral("1"));
         job->addMetaData(QStringLiteral("no-auth-prompt"), QStringLiteral("true"));
         q->addSubjob(job);
     }
@@ -536,15 +536,15 @@ bool PreviewJobPrivate::statResultThumbnail()
     origName = url.toEncoded();
 
     QCryptographicHash md5(QCryptographicHash::Md5);
-    md5.addData(QFile::encodeName(origName));
-    thumbName = QFile::encodeName(md5.result().toHex()) + ".png";
+    md5.addData(QFile::encodeName(QString::fromUtf8(origName)));
+    thumbName = QString::fromUtf8(QFile::encodeName(QString::fromLatin1(md5.result().toHex()))) + QLatin1String(".png");
 
     QImage thumb;
     if (!thumb.load(thumbPath + thumbName)) {
         return false;
     }
 
-    if (thumb.text(QStringLiteral("Thumb::URI")) != origName ||
+    if (thumb.text(QStringLiteral("Thumb::URI")) != QString::fromUtf8(origName) ||
             thumb.text(QStringLiteral("Thumb::MTime")).toLongLong() != tOrig.toTime_t()) {
         return false;
     }
@@ -698,14 +698,14 @@ void PreviewJobPrivate::slotThumbData(KIO::Job *, const QByteArray &data)
     }
 
     if (save) {
-        thumb.setText(QStringLiteral("Thumb::URI"), origName);
+        thumb.setText(QStringLiteral("Thumb::URI"), QString::fromUtf8(origName));
         thumb.setText(QStringLiteral("Thumb::MTime"), QString::number(tOrig.toTime_t()));
         thumb.setText(QStringLiteral("Thumb::Size"), number(currentItem.item.size()));
         thumb.setText(QStringLiteral("Thumb::Mimetype"), currentItem.item.mimetype());
         QString thumbnailerVersion = currentItem.plugin->property(QStringLiteral("ThumbnailerVersion"), QVariant::String).toString();
-        QString signature = QString("KDE Thumbnail Generator " + currentItem.plugin->name());
+        QString signature = QLatin1String("KDE Thumbnail Generator ") + currentItem.plugin->name();
         if (!thumbnailerVersion.isEmpty()) {
-            signature.append(" (v" + thumbnailerVersion + ')');
+            signature.append(QLatin1String(" (v") + thumbnailerVersion + QLatin1Char(')'));
         }
         thumb.setText(QStringLiteral("Software"), signature);
         QSaveFile saveFile(thumbPath + thumbName);
@@ -779,6 +779,7 @@ PreviewJob *KIO::filePreview(const QList<QUrl> &items, int width, int height,
                              const QStringList *enabledPlugins)
 {
     KFileItemList fileItems;
+    fileItems.reserve(items.size());
     for (QList<QUrl>::const_iterator it = items.begin(); it != items.end(); ++it) {
         Q_ASSERT((*it).isValid());   // please call us with valid urls only
         fileItems.append(KFileItem(*it));
